@@ -1,7 +1,7 @@
 package Finance::BTCIndo;
 
-our $DATE = '2017-06-01'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-03'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -127,9 +127,15 @@ sub get_price_history {
     $args{pair} //= "btc_idr";
     $args{pair} =~ /\A\w{3}_\w{3}\z/
         or die "Invalid pair: must be in the form of 'abc_xyz'";
-    # XXX since, end?
+    $args{period} //= 'day';
+    $args{period} =~ /\A(day|all)\z/
+        or die "Invalid period: must be day|all";
 
-    $self->_get_json("$url_prefix/api/$args{pair}/chartdata");
+    if ($args{period} eq 'all') {
+        $self->_get_json("$url_prefix/api/$args{pair}/chartdata");
+    } else {
+        $self->_get_json("$url_prefix/api/$args{pair}/chart_1d");
+    }
 }
 
 sub get_info {
@@ -211,7 +217,7 @@ Finance::BTCIndo - Trade with bitcoin.co.id (VIP) using Perl
 
 =head1 VERSION
 
-This document describes version 0.004 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-06-01.
+This document describes version 0.005 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-06-03.
 
 =head1 SYNOPSIS
 
@@ -358,7 +364,8 @@ Optional, e.g. eth_btc. Default: btc_idr.
 
 =head2 get_price_history
 
-Public API (undocumented). The API method name is C<chartdata>.
+Public API (undocumented). The API method name is either C<chartdata> or
+C<chart_1d>.
 
 This function returns an array of records. Each record is an array with the
 following data:
@@ -373,6 +380,11 @@ Arguments:
 
 Optional, e.g. eth_btc. Default: btc_idr.
 
+=item * period => str (all|day, default: day)
+
+Specify period. C<all> means since exchange began operation (Feb 2014). C<day>
+means in the last ~24h.
+
 =back
 
 =head2 tapi
